import React from 'react'
import { Client, withClient } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { Konnector, Trigger } from 'doctypes'
import OAuthForm from 'components/ContentComponents/OAuth/OAuthForm'
import StyledButton from 'components/CommonKit/Button/StyledButton'
import { AccountService } from 'services/accountService'
import { TriggerService } from 'services/triggersService'

interface KonnectorOAuthFormProps {
  konnector: Konnector
  siteLink: string
  onSuccess: Function
  loading: boolean
  client: Client
  t: Function
}

const KonnectorOAuthForm: React.FC<KonnectorOAuthFormProps> = ({
  konnector,
  siteLink,
  onSuccess,
  loading,
  client,
  t,
}: KonnectorOAuthFormProps) => {
  const handleSuccess = async (accountId: string) => {
    const account = await AccountService.getAccount(client, accountId)
    if (!account) {
      onSuccess(null, null)
    }
    const triggersServices = new TriggerService(client, account, konnector)
    const trigger: Trigger = await triggersServices.createTrigger()
    onSuccess(account, trigger)
  }
  return (
    <div className="koauthform">
      <div className="koauthform-text text-16-normal">
        {t('auth.' + konnector.slug + '.connect.info')}
      </div>
      <div className="koauthform-button">
        <OAuthForm konnector={konnector} onSuccess={handleSuccess} />
      </div>
      <div className="koauthform-text text-16-bold">
        <div className="text-16-bold">
          {t('auth.' + konnector.slug + '.no_account.title')}
        </div>
        <div className="text-16-normal">
          {t('auth.' + konnector.slug + '.no_account.text')}
        </div>
      </div>
      <div className="koauthform-button">
        <StyledButton
          type="button"
          color="secondary"
          disabled={loading}
          onClick={() => window.open(siteLink, '_blank')}
        >
          {t('auth.' + konnector.slug + '.create_account')}
        </StyledButton>
      </div>
    </div>
  )
}

export default translate()(withClient(KonnectorOAuthForm))
