import React, { useState } from 'react'
import { Client, withClient } from 'cozy-client'
import { translate } from 'cozy-ui/react/I18n'

import { Konnector } from 'doctypes'
import { OAuthWindow } from 'cozy-harvest-lib/dist/components/OAuthWindow'

import iconEnedisLogo from 'assets/icons/visu/enedis-logo.svg'
import StyledAuthButton from 'components/CommonKit/Button/StyledAuthButton'
import StyledIcon from 'components/CommonKit/Icon/StyledIcon'
import StyledBlackSpinner from 'components/CommonKit/Spinner/StyledBlackSpinner'

interface OAuthFormProps {
  konnector: Konnector
  onSuccess: Function
  loginFailed: boolean
  client: Client
  t: Function
}

const OAuthForm: React.FC<OAuthFormProps> = ({
  konnector,
  onSuccess,
  client,
  t,
}: OAuthFormProps) => {
  const IDLE = 'idle'
  const WAITING = 'waiting'

  const [status, setStatus] = useState<string>(IDLE)

  function endOAuth() {
    setStatus(IDLE)
  }
  function startOAuth() {
    setStatus(WAITING)
  }
  function handleAccountId(accountId: string) {
    endOAuth()
    onSuccess(accountId)
  }
  function handleSubmit() {
    startOAuth()
  }
  function handleOAuthCancel() {
    endOAuth()
  }

  const isWaiting = status === WAITING
  return !konnector ? null : (
    <>
      <StyledAuthButton
        type="button"
        color="primary"
        onClick={handleSubmit}
        disabled={isWaiting}
      >
        <div className="authform-button-content">
          <div className="authform-button-content-icon">
            {isWaiting ? (
              <StyledBlackSpinner size={48} />
            ) : (
              <StyledIcon icon={iconEnedisLogo} size={48} />
            )}
          </div>
          <div className="authform-button-text text-18-bold">
            <div>{t('auth.' + konnector.slug + '.connect.label1')}</div>
            <div>{t('auth.' + konnector.slug + '.connect.label2')}</div>
          </div>
        </div>
      </StyledAuthButton>
      {isWaiting && (
        <OAuthWindow
          client={client}
          konnector={konnector}
          onSuccess={handleAccountId}
          onCancel={handleOAuthCancel}
          t={t}
        />
      )}
    </>
  )
}

export default translate()(withClient(OAuthForm))
